#!/bin/sh
# Function: Removes existing NL1 application developer folders in $RAD_HOME
# and replaces them with updated ones.
# Expects the home location of RAD and RWD (for runtimes/ directory) to be
# passed in as arguments.

RAD_HOME=$1
RWD_HOME=$2
LOG_FILE="/tmp/rad.rup.nl1.update.log"
RAD_CONFIG="rup.configuration.nl1.zip"
ROLLBAK_DIR="../rup.configuration.rollback.nl1"

### Main Routine ###
PWD=`pwd`
echo "Starting RAD RUP NL1 update in $PWD" > $LOG_FILE

# Prep rollback environment
/bin/cp -f rup_rollbak_4_rad_linux.nl1.sh ../

# Check for existence of NL1 configurations
if [ -d $RAD_HOME/RUP\ Configuration/application\ developer.fr ] || 
   [ -d $RAD_HOME/RUP\ Configuration/application\ developer.ja ] || 
   [ -d $RAD_HOME/RUP\ Configuration/application\ developer.ko ] || 
   [ -d $RAD_HOME/RUP\ Configuration/application_developer.pt_BR ] || 
   [ -d $RAD_HOME/RUP\ Configuration/application\ developer.zh_CN ]; then
        NL1=1
fi

if [ $NL1 ]; then                                                                                
  # Prep rollback configuration environment
  # Create $ROLLBAK_DIR only if NL1 configurations are present
  /bin/mkdir -p $ROLLBAK_DIR

  # Backup existing applicaiton developer folders for future rollback
  /bin/mv -f $RAD_HOME/RUP\ Configuration/application\ developer.* $ROLLBAK_DIR/
  /bin/mv -f $RAD_HOME/RUP\ Configuration/application_developer.pt_BR $ROLLBAK_DIR/
  echo "Backed up existing NL1 configurations." >> $LOG_FILE
                                                                                
  # Test for existence of jar utility and execute them
  if [ -x $RWD_HOME/runtimes/base_v6_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v6_stub/java/bin/jar xf $RAD_CONFIG
  elif [ -x $RWD_HOME/runtimes/base_v51_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v51_stub/java/bin/jar xf $RAD_CONFIG 
  elif [ -x $RWD_HOME/runtimes/base_v5_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v5_stub/java/bin/jar xf $RAD_CONFIG
  else
    echo "Cannot find executable jar file(s) in $RWD_HOME/runtimes" >> $LOG_FILE
    echo "Update of RUP NL1 configurations failed!" >> $LOG_FILE
    exit 1
  fi
  /bin/mv -f RUP\ Configuration/application\ developer* $RAD_HOME/RUP\ Configuration/
  echo "Update of RUP NL1 configurations succeeded." >> $LOG_FILE
else
  echo "Update not performed because no NL1 configurations were found in $RAD_HOME/RUP Configuration" >> $LOG_FILE

fi
